yt.visualization.volume_rendering.camera.StereoPairCamera.zoom — The yt Project 3.2-dev documentation

# yt.visualization.volume_rendering.camera.StereoPairCamera.zoom

`StereoPairCamera.` `zoom`(factor)

  Change the distance to the focal point.

  This will zoom the camera in by some factor toward the focal point, along the current view direction, modifying the left/right and up/down extents as well.

  Parameters: | factor : float The factor by which to reduce the distance to the focal point.

  Notes

  You will need to call snapshot() again to get a new image.